结语 | NoneBot
Description: 跨平台 Python 异步 QQ 机器人框架

- master next
- 2.0.0a15 current
- 2.0.0a13.post1
- 2.0.0a10
- 2.0.0a8.post2
- 2.0.0a7

- 开始

  - 概览
  - 安装
  - 开始使用
  - 创建一个完整的项目
  - 基本配置

- 编写插件

  - 加载插件
  - 创建插件
  - 注册事件响应器
  - 事件处理
  - 结语

- 协议适配

  - CQHTTP 协议使用指南
  - 钉钉机器人使用指南

# # 结语

至此，相信你已经能够写出一个基础的插件了。这里给出几个小提示：

- 请千万注意事件处理器的优先级设定
- 在匹配规则中请勿使用耗时极长的函数
- 同一个用户可以跨群(私聊)继续他的事件处理（除非做出权限限制，将在后续介绍）

如果「指南」还不能满足你，前往 进阶 查看更多的功能信息。

← 事件处理 CQHTTP 协议使用指南 →